#ifndef __UDS_2FSERVICE_INTERNA_H
#define __UDS_2FSERVICE_INTERNA_H

#include "TYW_stdint.h"
#include "UDS_Common.h"

void BuzzerTest(uint8_t ControlStatus, uint8_t BuzzerStatus);
void GaugeTest(uint8_t ControlStatus, uint8_t GaugeType, uint8_t GaugeStatus);
void LampWarningTest(uint8_t ControlStatus, uint8_t LampWarningStatus);
uint8_t Get_DIAG_Soundsts(void);
void Set_DIAG_Soundsts(uint8_t Soundsts);
void Set_DIAG_TelltalesCtrlsts(uint8_t n);
void Set_DIAG_Vehicle_Speedsts(uint8_t n);
void Set_DIAG_LCDsts(uint8_t n);
void Set_DIAG_Engine_Speedsts(uint8_t n);
void Set_DIAG_BACKLIGHTsts(uint8_t n);
uint8_t Get_DIAG_Vehicle_Speedsts(void);
uint8_t Get_DIAG_Engine_Speedsts(void);
uint8_t Get_DIAG_BACKLIGHTsts(void);
uint8_t Get_DIAG_TelltalesCtrlsts(void);
uint8_t Get_DIAG_LCDsts(void);

#endif