#include "UDS_10Service_Internal.h"
#include "Telltales_user.h"
#include "Telltales_Lib.h"

/**
  *10服务重置27服务标志位
  */
void UDS_10Service_S27Init(void)
{
    Ser27_ChangeSessionHandle();
}

/**
  *10服务重置28服务标志位
  */
void UDS_10Service_S28Init(void)
{
    ControlMessageCommunication(networkManagementMsgAndnormalMsg, enableRxAndTx);
}

/**
  *10服务重置2F服务标志位
  */
void UDS_10Service_S2FInit(void)
{
  Set_DIAG_Soundsts(0);
  Set_DIAG_TelltalesCtrlsts(0);
  Set_DIAG_Vehicle_Speedsts(0);
  Set_DIAG_LCDsts(0);
  Set_DIAG_Engine_Speedsts(0);
  Set_DIAG_BACKLIGHTsts(0);
  
}
/**
  *10服务重置31服务标志位
  */
void UDS_10Service_S31Init(void)
{
    S31DID0203RequestFlag = 0;
  
}

/**
  *10服务重置85服务标志位
  */
void UDS_10Service_S85Init(void)
{
    OpenDTCTest();
}

/**
  *写入跳转标志位
  *@param Flag 跳转标志
  */
void WriteJumpBootStatusToDFlash(uint32_t Flag)
{
    DiagFlag.JumpToBootFlag = Flag;
    DFlash_WriteData(WriteProgramValidFlagAddr, (uint32_t *)&DiagFlag.Flag, sizeof(DiagFlag) , WriteFDL);
}